var connection = {
    url: "jdbc:oracle:thin:@//<>BIRT_ORA_HOST<>:<>BIRT_ORA_PORT<>/<>BIRT_ORA_DBNAME<>",
    userName: "<>BIRT_ORA_USER<>",
    password: "<>BIRT_ORA_PASSWORD<>",
    useWallet: <>BIRT_ORA_WALLET_BOOL<>,
    isSaaSTek: <>TEK_SAAS_BOOL<>,
    vpdUserNamePrefix: "<>BIRT_ORA_WALLET_PREFIX<>",
    walletPrefix: "<>BIRT_ORA_WALLET_PREFIX<>",
    driverClass: "oracle.jdbc.driver.OracleDriver"
}

/**
  * @desc - retorna um objeto das informações utilizadas para acessar a base do relatório
  * @return object 
  */
function getConnection() {
    return connection;
}

/**
  * @desc - retornar um parâmetro que está sendo enviado ao relatório.
  * @param string parameterName - nome do parâmetro desejado
  * @return string
  */
function getParameter(parameterName) {
    return reportContext.getParameterValue(parameterName) || '';
}

/**
  * @desc - retorna o driver url para acesso à base de dados
  * @return string
  */
function getUrl()  {
    var connection = getConnection();
    url = connection.url;

    if (connection.useWallet) {
        var nrorg = "";
        if (connection.isSaaSTek) {
            nrorg = getParameter('NRORG') || getParameter('P_NRORG');
        }
        url = 'jdbc:oracle:thin:/@'+ connection.walletPrefix + nrorg;
    }

    return url;
}

/**
  * @desc - retorna o usuário de acesso à base de dados
  * @return string
  */
function getUserName() {
    var connection = getConnection();
    var nrorg = getParameter('NRORG') || getParameter('P_NRORG');

    if (connection.useWallet) {
        return null;
    }
    
    if (connection.isSaaSTek) {
        return connection.vpdUserNamePrefix + nrorg;
    }

    return connection.userName;
}

/**
  * @desc - retorna o senha de acesso à base de dados
  * @return string
  */
function getPassword() {
    var connection = getConnection();
    var password = connection.password;

    if (connection.useWallet) {
        password = null;
    }

    return password;
}

/**
  * @desc - retorna o driver utilizado para o acesso à base de dados
  * @return string
  */
function getDriverClass() {
    var connection = getConnection();
    return connection.driverClass;
}

function formatKey(key){
    const INTERPOLATION_KEY = '__';
    return key ? INTERPOLATION_KEY+key+INTERPOLATION_KEY : key;
}

function bindVariables(str, params){
    var oldStr = "";
    do{
      oldStr = str;
      for ( var key in params ) {
        str = str.replace(formatKey(key), params[key]);
      }  
    } while(oldStr !== str);
    return str;
}

function getMessageByLang(originalStr, params){
    var locale = reportContext.getLocale();
    var firstTranslate = reportContext.getMessage(originalStr, locale);
    var newStr = reportContext.getMessage(firstTranslate, locale) || firstTranslate ||  originalStr; 
    return !params ? newStr : bindVariables(newStr, params);
}

function translate(mensagem, paramsMsg){
    try {
      var codeStart = mensagem.indexOf("_MSGSTA_");
      var codeEnd = mensagem.indexOf("_MSGEND_");
      if (codeStart >= 0 && codeEnd >= 0){
        var msgStart = codeStart + "_MSGSTA_".length;
        var msgEnd = codeEnd;
          var paramstring = mensagem.substring(msgStart, msgEnd);
          var params = paramstring.split("$$");
          var msgcode = params.shift(params);   
          mensagem = msgcode;
          paramsMsg = {};
          if(params.length > 0){  
              for(var i = 0; i < params.length; i++) {
                paramsMsg['PARAM'+i] = params[i];
              }            
          }  
      }
    } finally {
      return getMessageByLang(mensagem, paramsMsg);
    }
}